@@ -1,10 +1,10 @@
 import configparser
 import logging
 import os
+import re
 import warnings
 
 from testit_python_commons.models.adapter_mode import AdapterMode
-from testit_python_commons.services.utils import Utils
 
 
 class AppProperties:
@@ -51,16 +51,16 @@ class AppProperties:
 
             if parser.has_section('testit'):
                 for key, value in parser.items('testit'):
-                    properties[key] = Utils.search_in_environ(value)
+                    properties[key] = cls.__search_in_environ(value)
 
             if parser.has_section('debug'):
                 if parser.has_option('debug', 'tmsproxy'):
-                    properties['tmsproxy'] = Utils.search_in_environ(
+                    properties['tmsproxy'] = cls.__search_in_environ(
                         parser.get('debug', 'tmsproxy'))
 
                 if parser.has_option('debug', '__dev'):
-                    properties['logs'] = Utils.search_in_environ(
-                        parser.get('debug', '__dev'))
+                    properties['logs'] = cls.__search_in_environ(
+                        parser.get('debug', '__dev')).lower()
 
             if 'privatetoken' in properties:
                 warnings.warn(
@@ -100,6 +100,9 @@ class AppProperties:
         if hasattr(option, 'set_adapter_mode') and option.set_adapter_mode:
             cli_properties['adaptermode'] = option.set_adapter_mode
 
+        if hasattr(option, 'set_cert_validation') and option.set_cert_validation:
+            cli_properties['certvalidation'] = option.set_cert_validation
+
         return cli_properties
 
     @classmethod
@@ -130,6 +133,9 @@ class AppProperties:
         if f'{cls.__env_prefix}_ADAPTER_MODE' in os.environ.keys():
             env_properties['adaptermode'] = os.environ.get(f'{cls.__env_prefix}_ADAPTER_MODE')
 
+        if f'{cls.__env_prefix}_CERT_VALIDATION' in os.environ.keys():
+            env_properties['certvalidation'] = os.environ.get(f'{cls.__env_prefix}_CERT_VALIDATION')
+
         return env_properties
 
     @staticmethod
@@ -163,3 +169,13 @@ class AppProperties:
         if properties.get('configurationid') is None:
             logging.error('Configuration ID was not found!')
             raise SystemExit
+
+        if properties.get('certvalidation'):
+            properties['certvalidation'] = properties['certvalidation'].lower()
+
+    @staticmethod
+    def __search_in_environ(var_name: str):
+        if re.fullmatch(r'{[a-zA-Z_]\w*}', var_name) and var_name[1:-1] in os.environ:
+            return os.environ[var_name[1:-1]]
+
+        return var_name
