@@ -1,43 +1,49 @@
 import os
 import uuid
 
-import testit_python_commons.client.api_client as api_client
-from testit_python_commons.app_properties import AppProperties
-from testit_python_commons.models.adapter_mode import AdapterMode
+from testit_python_commons.client.api_client import ApiClientWorker
+from testit_python_commons.client.client_configuration import ClientConfiguration
 from testit_python_commons.services.adapter_manager_configuration import AdapterManagerConfiguration
+from testit_python_commons.models.adapter_mode import AdapterMode
+from testit_python_commons.services.logger import adapter_logger
 
 
 class AdapterManager:
+    def __init__(
+            self,
+            adapter_configuration: AdapterManagerConfiguration,
+            client_configuration: ClientConfiguration):
+        self.__config = adapter_configuration
+        self.__api_client = ApiClientWorker(client_configuration)
 
-    def __init__(self, option=None):
-        app_properties = AppProperties.load_properties(option)
-        client_configuration = api_client.ClientConfiguration(app_properties)
-        self.__config = AdapterManagerConfiguration(app_properties)
-
-        self.__api_client = api_client.ApiClientWorker(client_configuration)
-
+    @adapter_logger
     def set_test_run_id(self, test_run_id: str):
         self.__config.set_test_run_id(test_run_id)
         self.__api_client.set_test_run_id(test_run_id)
 
+    @adapter_logger
     def get_test_run_id(self):
         if self.__config.get_mode() != AdapterMode.NEW_TEST_RUN:
             return self.__config.get_test_run_id()
 
         return self.__api_client.create_test_run()
 
+    @adapter_logger
     def get_autotests_for_launch(self):
         if self.__config.get_mode() == AdapterMode.USE_FILTER:
             return self.__api_client.get_autotests_by_test_run_id()
 
         return
 
+    @adapter_logger
     def write_test(self, test: dict):
         self.__api_client.write_test(test)
 
+    @adapter_logger
     def load_attachments(self, attach_paths: list or tuple):
         return self.__api_client.load_attachments(attach_paths)
 
+    @adapter_logger
     def create_attachment(self, body: str, name: str):
         if name is None:
             name = str(uuid.uuid4()) + '-attachment.txt'
